API
===

.. automodule:: catio

    ``catio``
    -----------------------------------

This is the internal API reference for catio

.. data:: catio.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
